@@ -35,22 +35,21 @@ if __name__ == "__main__":
         nb_clusters = np.random.randint(low=5, high=40)
         min_corr = np.random.uniform(low=0.75, high=0.95)
         max_corr = np.random.uniform(low=0.05, high=0.25)
-        h_avg_csize = np.random.randint(low=10, high=20)
-        w_avg_csize = np.random.randint(low=10, high=100)
+        h_size = np.random.randint(low=100, high=200)
+        w_size = np.random.randint(low=100, high=200)
         eps = np.random.uniform(low=0.0, high=epsilon)
+        wclust_factor = np.random.uniform(0.25, 1.0)
 
-        generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                      min_intra_corr=min_corr,
-                                                      max_inter_corr=max_corr,
-                                                      h_avg_clust_size=h_avg_csize,
-                                                      w_avg_clust_size=w_avg_csize,
-                                                      epsilon=eps,
-                                                      random_norms=rand_norms)
+        generated_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
+                                                               n_obs=w_size, min_intra_corr=min_corr,
+                                                               max_inter_corr=max_corr, epsilon=eps,
+                                                               random_norms=rand_norms,
+                                                               wclust_factor=wclust_factor)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
         # generated_M.to_csv(res_path / "random_nmf" / f"M_t{itrial}_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
         #                                f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}.csv",
         #                    float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=3, ncmax=45)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=2, ncmax=45)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
 
         if itrial % writefreq == 0:
