@@ -234,19 +234,15 @@ if __name__ == "__main__":
         min_corr = 0.90
         max_corr = np.random.uniform(low=0.05, high=0.25)
         max_corr = 0.10
-        h_avg_csize = np.random.randint(low=10, high=20)
-        h_avg_csize = 20
-        w_avg_csize = np.random.randint(low=10, high=100)
-        w_avg_csize = 40
+        h_size = np.random.randint(low=10, high=20)
+        h_size = 20
+        w_size = np.random.randint(low=10, high=100)
+        w_size = 40
         rnd_norms = False
         # eps = np.random.uniform(low=0.0, high=0.25)
         eps = 0.0
-        gen_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                min_intra_corr=min_corr,
-                                                max_inter_corr=max_corr,
-                                                h_avg_clust_size=h_avg_csize,
-                                                w_avg_clust_size=w_avg_csize,
-                                                epsilon=eps,
+        gen_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
+                                                min_intra_corr=min_corr, max_inter_corr=max_corr, epsilon=eps,
                                                 random_norms=rnd_norms)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
@@ -277,29 +273,28 @@ if __name__ == "__main__":
 
     if os.getenv("imp_do_nmf_with_missings", "False").lower() == "true":
 
-        nb_clusters = 1
-        min_corr = 0.9
-        max_corr = 0.10
-        h_avg_csize = 20
-        w_avg_csize = 20
-        eps = 0
+        nb_clusters = 5
+        min_corr = 0.7
+        max_corr = 0.40
+        h_size = 200
+        w_size = 100
+        eps = 0.10
+        wclust_factor = np.random.uniform(0.25, 1.0)
         random_norms = True
         censor_rate = 0.0
         censor_indices_list = [[],
                                [[0, 0]],
                                [[0, 0], [1, 2]]]
-        gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                                         min_intra_corr=min_corr,
-                                                                         max_inter_corr=max_corr,
-                                                                         h_avg_clust_size=h_avg_csize,
-                                                                         w_avg_clust_size=w_avg_csize,
-                                                                         epsilon=eps,
-                                                                         random_norms=random_norms)
+        gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
+                                                                         n_obs=w_size, min_intra_corr=min_corr,
+                                                                         max_inter_corr=max_corr, epsilon=eps,
+                                                                         random_norms=random_norms,
+                                                                         wclust_factor=wclust_factor)
         for censor_indices in censor_indices_list:
 
             utl.censor_data(mat=gen_m, censored_indices=censor_indices, inplace=True)
             rnstr = "RandNorms" if random_norms else "ConstNorms"
-            wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
+            wh_name = f"M{w_size}x{h_size}_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
                       f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_indices}.csv"
             gen_m.to_csv(res_path / "random_nmf" / wh_name,
                          float_format="%.4f")
@@ -311,7 +306,7 @@ if __name__ == "__main__":
                          float_format="%.4f")
             nmf_h.to_csv(res_path / "random_nmf" / f"H_{wh_name}",
                          float_format="%.4f")
-            df_scree_plot = nmf.generate_scree_plot(gen_m, ncmin=1, ncmax=10)
+            df_scree_plot = nmf.generate_scree_plot(gen_m, ncmin=1, ncmax=15)
             df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
 
     if os.getenv("imp_do_screeplot_tests", "False").lower() == "true":
@@ -320,8 +315,8 @@ if __name__ == "__main__":
         nb_clusters = 1
         min_corr = 0.9
         max_corr = 0.10
-        h_avg_csize = 40
-        w_avg_csize = 30
+        h_size = 40
+        w_size = 30
         eps = 0
         random_norms = True
         censor_rate = 0.0
@@ -346,12 +341,9 @@ if __name__ == "__main__":
             else:
                 wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
-                gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                                         min_intra_corr=min_corr,
-                                                                         max_inter_corr=max_corr,
-                                                                         h_avg_clust_size=h_avg_csize,
-                                                                         w_avg_clust_size=w_avg_csize,
-                                                                         epsilon=eps,
+                gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
+                                                                         n_obs=w_size, min_intra_corr=min_corr,
+                                                                         max_inter_corr=max_corr, epsilon=eps,
                                                                          random_norms=random_norms)
 
             utl.censor_data(mat=gen_M, p=censor_rate, inplace=True)
